Class: ContentBlockTools::ContentBlock
- Inherits:
-
Object
- Object
- ContentBlockTools::ContentBlock
- Defined in:
- lib/content_block_tools/content_block.rb
Overview
Defines a Content Block
Constant Summary collapse
- CONTENT_BLOCK_PREFIX =
"content_block_".freeze
Instance Attribute Summary collapse
-
#content_id ⇒ String
readonly
The content UUID for a block.
-
#details ⇒ Hash
readonly
A hash that contains the details of the content block.
-
#document_type ⇒ String
readonly
The document type of the content block - this will be used to work out which Presenter will be used to render the content block.
-
#embed_code ⇒ String
readonly
The embed_code used for a block containing optional field name.
-
#format ⇒ String
readonly
The format specifier from the embed code, used to control rendering output.
-
#title ⇒ String
readonly
A title for the content block.
Instance Method Summary collapse
-
#initialize(content_id:, title:, document_type:, details:, embed_code:) ⇒ ContentBlock
constructor
A new instance of ContentBlock.
-
#render ⇒ String
Renders the content block to HTML using the appropriate component or presenter.
Constructor Details
#initialize(content_id:, title:, document_type:, details:, embed_code:) ⇒ ContentBlock
Returns a new instance of ContentBlock.
52 53 54 55 56 57 58 |
# File 'lib/content_block_tools/content_block.rb', line 52 def initialize(content_id:, title:, document_type:, details:, embed_code:) @content_id = content_id @title = title @document_type = document_type @details = details @embed_code = end |
Instance Attribute Details
#content_id ⇒ String (readonly)
The content UUID for a block
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/content_block_tools/content_block.rb', line 47 class ContentBlock CONTENT_BLOCK_PREFIX = "content_block_".freeze attr_reader :content_id, :title, :embed_code def initialize(content_id:, title:, document_type:, details:, embed_code:) @content_id = content_id @title = title @document_type = document_type @details = details @embed_code = end # Renders the content block to HTML using the appropriate component or presenter # # @return [String] A HTML representation of the content block # @see Renderer def render Renderer.new(self).render end def details @details.deep_symbolize_keys end def document_type @document_type.delete_prefix(CONTENT_BLOCK_PREFIX) end def format EmbedCode.new().format end end |
#details ⇒ Hash (readonly)
A hash that contains the details of the content block
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/content_block_tools/content_block.rb', line 47 class ContentBlock CONTENT_BLOCK_PREFIX = "content_block_".freeze attr_reader :content_id, :title, :embed_code def initialize(content_id:, title:, document_type:, details:, embed_code:) @content_id = content_id @title = title @document_type = document_type @details = details @embed_code = end # Renders the content block to HTML using the appropriate component or presenter # # @return [String] A HTML representation of the content block # @see Renderer def render Renderer.new(self).render end def details @details.deep_symbolize_keys end def document_type @document_type.delete_prefix(CONTENT_BLOCK_PREFIX) end def format EmbedCode.new().format end end |
#document_type ⇒ String (readonly)
The document type of the content block - this will be used to work out which Presenter will be used to render the content block. All supported document_types are documented in ContentBlockTools::ContentBlockReference::SUPPORTED_DOCUMENT_TYPES
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/content_block_tools/content_block.rb', line 47 class ContentBlock CONTENT_BLOCK_PREFIX = "content_block_".freeze attr_reader :content_id, :title, :embed_code def initialize(content_id:, title:, document_type:, details:, embed_code:) @content_id = content_id @title = title @document_type = document_type @details = details @embed_code = end # Renders the content block to HTML using the appropriate component or presenter # # @return [String] A HTML representation of the content block # @see Renderer def render Renderer.new(self).render end def details @details.deep_symbolize_keys end def document_type @document_type.delete_prefix(CONTENT_BLOCK_PREFIX) end def format EmbedCode.new().format end end |
#embed_code ⇒ String (readonly)
The embed_code used for a block containing optional field name
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/content_block_tools/content_block.rb', line 47 class ContentBlock CONTENT_BLOCK_PREFIX = "content_block_".freeze attr_reader :content_id, :title, :embed_code def initialize(content_id:, title:, document_type:, details:, embed_code:) @content_id = content_id @title = title @document_type = document_type @details = details @embed_code = end # Renders the content block to HTML using the appropriate component or presenter # # @return [String] A HTML representation of the content block # @see Renderer def render Renderer.new(self).render end def details @details.deep_symbolize_keys end def document_type @document_type.delete_prefix(CONTENT_BLOCK_PREFIX) end def format EmbedCode.new().format end end |
#format ⇒ String (readonly)
The format specifier from the embed code, used to control rendering output
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/content_block_tools/content_block.rb', line 47 class ContentBlock CONTENT_BLOCK_PREFIX = "content_block_".freeze attr_reader :content_id, :title, :embed_code def initialize(content_id:, title:, document_type:, details:, embed_code:) @content_id = content_id @title = title @document_type = document_type @details = details @embed_code = end # Renders the content block to HTML using the appropriate component or presenter # # @return [String] A HTML representation of the content block # @see Renderer def render Renderer.new(self).render end def details @details.deep_symbolize_keys end def document_type @document_type.delete_prefix(CONTENT_BLOCK_PREFIX) end def format EmbedCode.new().format end end |
#title ⇒ String (readonly)
A title for the content block
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/content_block_tools/content_block.rb', line 47 class ContentBlock CONTENT_BLOCK_PREFIX = "content_block_".freeze attr_reader :content_id, :title, :embed_code def initialize(content_id:, title:, document_type:, details:, embed_code:) @content_id = content_id @title = title @document_type = document_type @details = details @embed_code = end # Renders the content block to HTML using the appropriate component or presenter # # @return [String] A HTML representation of the content block # @see Renderer def render Renderer.new(self).render end def details @details.deep_symbolize_keys end def document_type @document_type.delete_prefix(CONTENT_BLOCK_PREFIX) end def format EmbedCode.new().format end end |