Class: ContentBlockTools::ContentBlock
- Inherits:
-
Object
- Object
- ContentBlockTools::ContentBlock
- Includes:
- ActionView::Helpers::TagHelper
- Defined in:
- lib/content_block_tools/content_block.rb
Overview
Defines a Content Block
Constant Summary collapse
- CONTENT_BLOCK_PREFIX =
"content_block_".freeze
Instance Attribute Summary collapse
-
#content_id ⇒ String
readonly
The content UUID for a block.
-
#details ⇒ Hash
readonly
A hash that contains the details of the content block.
-
#document_type ⇒ String
readonly
The document type of the content block - this will be used to work out which Presenter will be used to render the content block.
-
#embed_code ⇒ String
readonly
The embed_code used for a block containing optional field name.
-
#title ⇒ String
readonly
A title for the content block.
Instance Method Summary collapse
-
#initialize(content_id:, title:, document_type:, details:, embed_code:) ⇒ ContentBlock
constructor
A new instance of ContentBlock.
-
#render ⇒ string
Calls the appropriate presenter class to return a HTML representation of a content block.
Constructor Details
#initialize(content_id:, title:, document_type:, details:, embed_code:) ⇒ ContentBlock
Returns a new instance of ContentBlock.
48 49 50 51 52 53 54 |
# File 'lib/content_block_tools/content_block.rb', line 48 def initialize(content_id:, title:, document_type:, details:, embed_code:) @content_id = content_id @title = title @document_type = document_type @details = details @embed_code = end |
Instance Attribute Details
#content_id ⇒ String (readonly)
The content UUID for a block
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/content_block_tools/content_block.rb', line 41 class ContentBlock include ActionView::Helpers::TagHelper CONTENT_BLOCK_PREFIX = "content_block_".freeze attr_reader :content_id, :title, :embed_code def initialize(content_id:, title:, document_type:, details:, embed_code:) @content_id = content_id @title = title @document_type = document_type @details = details @embed_code = end # Calls the appropriate presenter class to return a HTML representation of a content # block. Defaults to {Presenters::BasePresenter} # # @return [string] A HTML representation of the content block def render content_tag( base_tag, content, class: %W[content-block content-block--#{document_type}], data: { content_block: "", document_type: document_type, content_id: content_id, embed_code: , }, ) end def details @details.deep_symbolize_keys end def document_type @document_type.delete_prefix(CONTENT_BLOCK_PREFIX) end private def base_tag rendering_block? ? :div : :span end def content field_names.present? ? field_or_block_content : component.new(content_block: self).render rescue NameError title end def field_or_block_content content = details.dig(*field_names) case content when String field_presenter(field_names.last).new(content).render when Hash component.new(content_block: self, block_type: field_names.first, block_name: field_names.last).render else ContentBlockTools.logger.warn("Content not found for content block #{content_id} and fields #{field_names}") end end def rendering_block? !field_names.present? || details.dig(*field_names).is_a?(Hash) end def component "ContentBlockTools::#{document_type.camelize}Component".constantize end def field_presenter(field) "ContentBlockTools::Presenters::FieldPresenters::#{document_type.camelize}::#{field.to_s.camelize}Presenter".constantize rescue NameError ContentBlockTools::Presenters::FieldPresenters::BasePresenter end def field_names @field_names ||= begin = ContentBlockReference::EMBED_REGEX.match() if .present? all_fields = [4]&.reverse&.chomp("/")&.reverse all_fields&.split("/")&.map do |item| is_number?(item) ? item.to_i : item.to_sym end end end end def is_number?(item) Float(item, exception: false) end end |
#details ⇒ Hash (readonly)
A hash that contains the details of the content block
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/content_block_tools/content_block.rb', line 41 class ContentBlock include ActionView::Helpers::TagHelper CONTENT_BLOCK_PREFIX = "content_block_".freeze attr_reader :content_id, :title, :embed_code def initialize(content_id:, title:, document_type:, details:, embed_code:) @content_id = content_id @title = title @document_type = document_type @details = details @embed_code = end # Calls the appropriate presenter class to return a HTML representation of a content # block. Defaults to {Presenters::BasePresenter} # # @return [string] A HTML representation of the content block def render content_tag( base_tag, content, class: %W[content-block content-block--#{document_type}], data: { content_block: "", document_type: document_type, content_id: content_id, embed_code: , }, ) end def details @details.deep_symbolize_keys end def document_type @document_type.delete_prefix(CONTENT_BLOCK_PREFIX) end private def base_tag rendering_block? ? :div : :span end def content field_names.present? ? field_or_block_content : component.new(content_block: self).render rescue NameError title end def field_or_block_content content = details.dig(*field_names) case content when String field_presenter(field_names.last).new(content).render when Hash component.new(content_block: self, block_type: field_names.first, block_name: field_names.last).render else ContentBlockTools.logger.warn("Content not found for content block #{content_id} and fields #{field_names}") end end def rendering_block? !field_names.present? || details.dig(*field_names).is_a?(Hash) end def component "ContentBlockTools::#{document_type.camelize}Component".constantize end def field_presenter(field) "ContentBlockTools::Presenters::FieldPresenters::#{document_type.camelize}::#{field.to_s.camelize}Presenter".constantize rescue NameError ContentBlockTools::Presenters::FieldPresenters::BasePresenter end def field_names @field_names ||= begin = ContentBlockReference::EMBED_REGEX.match() if .present? all_fields = [4]&.reverse&.chomp("/")&.reverse all_fields&.split("/")&.map do |item| is_number?(item) ? item.to_i : item.to_sym end end end end def is_number?(item) Float(item, exception: false) end end |
#document_type ⇒ String (readonly)
The document type of the content block - this will be used to work out which Presenter will be used to render the content block. All supported document_types are documented in ContentBlockTools::ContentBlockReference::SUPPORTED_DOCUMENT_TYPES
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/content_block_tools/content_block.rb', line 41 class ContentBlock include ActionView::Helpers::TagHelper CONTENT_BLOCK_PREFIX = "content_block_".freeze attr_reader :content_id, :title, :embed_code def initialize(content_id:, title:, document_type:, details:, embed_code:) @content_id = content_id @title = title @document_type = document_type @details = details @embed_code = end # Calls the appropriate presenter class to return a HTML representation of a content # block. Defaults to {Presenters::BasePresenter} # # @return [string] A HTML representation of the content block def render content_tag( base_tag, content, class: %W[content-block content-block--#{document_type}], data: { content_block: "", document_type: document_type, content_id: content_id, embed_code: , }, ) end def details @details.deep_symbolize_keys end def document_type @document_type.delete_prefix(CONTENT_BLOCK_PREFIX) end private def base_tag rendering_block? ? :div : :span end def content field_names.present? ? field_or_block_content : component.new(content_block: self).render rescue NameError title end def field_or_block_content content = details.dig(*field_names) case content when String field_presenter(field_names.last).new(content).render when Hash component.new(content_block: self, block_type: field_names.first, block_name: field_names.last).render else ContentBlockTools.logger.warn("Content not found for content block #{content_id} and fields #{field_names}") end end def rendering_block? !field_names.present? || details.dig(*field_names).is_a?(Hash) end def component "ContentBlockTools::#{document_type.camelize}Component".constantize end def field_presenter(field) "ContentBlockTools::Presenters::FieldPresenters::#{document_type.camelize}::#{field.to_s.camelize}Presenter".constantize rescue NameError ContentBlockTools::Presenters::FieldPresenters::BasePresenter end def field_names @field_names ||= begin = ContentBlockReference::EMBED_REGEX.match() if .present? all_fields = [4]&.reverse&.chomp("/")&.reverse all_fields&.split("/")&.map do |item| is_number?(item) ? item.to_i : item.to_sym end end end end def is_number?(item) Float(item, exception: false) end end |
#embed_code ⇒ String (readonly)
The embed_code used for a block containing optional field name
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/content_block_tools/content_block.rb', line 41 class ContentBlock include ActionView::Helpers::TagHelper CONTENT_BLOCK_PREFIX = "content_block_".freeze attr_reader :content_id, :title, :embed_code def initialize(content_id:, title:, document_type:, details:, embed_code:) @content_id = content_id @title = title @document_type = document_type @details = details @embed_code = end # Calls the appropriate presenter class to return a HTML representation of a content # block. Defaults to {Presenters::BasePresenter} # # @return [string] A HTML representation of the content block def render content_tag( base_tag, content, class: %W[content-block content-block--#{document_type}], data: { content_block: "", document_type: document_type, content_id: content_id, embed_code: , }, ) end def details @details.deep_symbolize_keys end def document_type @document_type.delete_prefix(CONTENT_BLOCK_PREFIX) end private def base_tag rendering_block? ? :div : :span end def content field_names.present? ? field_or_block_content : component.new(content_block: self).render rescue NameError title end def field_or_block_content content = details.dig(*field_names) case content when String field_presenter(field_names.last).new(content).render when Hash component.new(content_block: self, block_type: field_names.first, block_name: field_names.last).render else ContentBlockTools.logger.warn("Content not found for content block #{content_id} and fields #{field_names}") end end def rendering_block? !field_names.present? || details.dig(*field_names).is_a?(Hash) end def component "ContentBlockTools::#{document_type.camelize}Component".constantize end def field_presenter(field) "ContentBlockTools::Presenters::FieldPresenters::#{document_type.camelize}::#{field.to_s.camelize}Presenter".constantize rescue NameError ContentBlockTools::Presenters::FieldPresenters::BasePresenter end def field_names @field_names ||= begin = ContentBlockReference::EMBED_REGEX.match() if .present? all_fields = [4]&.reverse&.chomp("/")&.reverse all_fields&.split("/")&.map do |item| is_number?(item) ? item.to_i : item.to_sym end end end end def is_number?(item) Float(item, exception: false) end end |
#title ⇒ String (readonly)
A title for the content block
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/content_block_tools/content_block.rb', line 41 class ContentBlock include ActionView::Helpers::TagHelper CONTENT_BLOCK_PREFIX = "content_block_".freeze attr_reader :content_id, :title, :embed_code def initialize(content_id:, title:, document_type:, details:, embed_code:) @content_id = content_id @title = title @document_type = document_type @details = details @embed_code = end # Calls the appropriate presenter class to return a HTML representation of a content # block. Defaults to {Presenters::BasePresenter} # # @return [string] A HTML representation of the content block def render content_tag( base_tag, content, class: %W[content-block content-block--#{document_type}], data: { content_block: "", document_type: document_type, content_id: content_id, embed_code: , }, ) end def details @details.deep_symbolize_keys end def document_type @document_type.delete_prefix(CONTENT_BLOCK_PREFIX) end private def base_tag rendering_block? ? :div : :span end def content field_names.present? ? field_or_block_content : component.new(content_block: self).render rescue NameError title end def field_or_block_content content = details.dig(*field_names) case content when String field_presenter(field_names.last).new(content).render when Hash component.new(content_block: self, block_type: field_names.first, block_name: field_names.last).render else ContentBlockTools.logger.warn("Content not found for content block #{content_id} and fields #{field_names}") end end def rendering_block? !field_names.present? || details.dig(*field_names).is_a?(Hash) end def component "ContentBlockTools::#{document_type.camelize}Component".constantize end def field_presenter(field) "ContentBlockTools::Presenters::FieldPresenters::#{document_type.camelize}::#{field.to_s.camelize}Presenter".constantize rescue NameError ContentBlockTools::Presenters::FieldPresenters::BasePresenter end def field_names @field_names ||= begin = ContentBlockReference::EMBED_REGEX.match() if .present? all_fields = [4]&.reverse&.chomp("/")&.reverse all_fields&.split("/")&.map do |item| is_number?(item) ? item.to_i : item.to_sym end end end end def is_number?(item) Float(item, exception: false) end end |
Instance Method Details
#render ⇒ string
Calls the appropriate presenter class to return a HTML representation of a content block. Defaults to Presenters::BasePresenter
60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/content_block_tools/content_block.rb', line 60 def render content_tag( base_tag, content, class: %W[content-block content-block--#{document_type}], data: { content_block: "", document_type: document_type, content_id: content_id, embed_code: , }, ) end |